@@ -1,8 +1,8 @@
 
 #' Set theme and default colors for Billboard charts
 #'
-#' @param name Name of the theme, possible values are : \code{"billboard"},
-#'  \code{"insight"}, \code{"graph"}, \code{"datalab"}.
+#' @param name Name of the theme, possible values are : `"billboard"`,
+#'  `"insight"`, `"graph"`, `"datalab"`, `"modern"`.
 #' 
 #' @note You can only use one theme and palette at a time (in Shiny applications or Markdown documents).
 #'
@@ -28,7 +28,7 @@
 #'   bb_legend(position = "inset", inset = list(anchor = "top-right")) %>% 
 #'   bb_labs(title = "Renewable energy production",
 #'           caption = "Data source: RTE (https://opendata.rte-france.com)")
-set_theme <- function(name = c("billboard", "insight", "graph", "datalab")) {
+set_theme <- function(name = c("billboard", "insight", "graph", "datalab", "modern")) {
   name <- match.arg(arg = name)
   options("billboard.theme" = paste0(name, ".min.css"))
 }
